module.exports = function (grunt) {
    'use strict';
    // Load all grunt tasks
    require('load-grunt-tasks')(grunt);
    // Show elapsed time at the end
    require('time-grunt')(grunt);

    // Project configuration.
    grunt.initConfig({
        // Metadata.
        pkg: grunt.file.readJSON('package.json'),
        banner: '/*! <%= pkg.name %> - v<%= pkg.version %> - ' +
        '<%= grunt.template.today("yyyy-mm-dd") %>\n' +
        '<%= pkg.homepage ? "* " + pkg.homepage + "\\n" : "" %>' +
        '* Copyright (c) <%= grunt.template.today("yyyy") %> <%= pkg.author.name %>;' +
        ' Licensed <%= pkg.licenses[0].type %> */\n',
        // Task configuration.
        clean: {
            files: ['dist']
        },
        concat: {
            options: {
                banner: '<%= banner %>',
                stripBanners: true
            },
            libs: {
                src: [
                    'node_modules/jquery/dist/jquery.js',
                    'node_modules/jquery-ui/ui/core.js',
                    'node_modules/jquery-ui/ui/widget.js',
                    'node_modules/jquery.cookie/jquery.cookie.js'
                ],
                dest: 'dist/libs.js'
            },
            dist: {
                src: ['src/uhr.js', 'src/uhr-*.js'],
                dest: 'dist/jquery.<%= pkg.name %>.complete.js'
            },
            main: {
                src: ['src/uhr.js'],
                dest: 'dist/jquery.<%= pkg.name %>.main.js'
            },
            base: {
                src: ['src/uhr.js', 'src/uhr-de_CH.js'],
                dest: 'dist/jquery.<%= pkg.name %>.base.js'
            },
            baselangs: {
                src: ['src/uhr-*.js'],
                exclude: ['src/uhr-de_CH.js'],
                dest: 'dist/jquery.<%= pkg.name %>.baselangs.js'
            },
            langs: {
                src: ['src/uhr-*.js'],
                dest: 'dist/jquery.<%= pkg.name %>.langs.js'
            }
        },
        uglify: {
            options: {
                banner: '<%= banner %>'
            },
            libs: {
                src: '<%= concat.libs.dest %>',
                dest: 'dist/libs.min.js'
            },
            dist: {
                src: '<%= concat.dist.dest %>',
                dest: 'dist/jquery.<%= pkg.name %>.complete.min.js'
            },
            main: {
                src: '<%= concat.main.dest %>',
                dest: 'dist/jquery.<%= pkg.name %>.main.min.js'
            },
            base: {
                src: '<%= concat.base.dest %>',
                dest: 'dist/jquery.<%= pkg.name %>.base.min.js'
            },
            baselangs: {
                src: '<%= concat.baselangs.dest %>',
                dest: 'dist/jquery.<%= pkg.name %>.baselangs.min.js'
            },
            langs: {
                src: '<%= concat.langs.dest %>',
                dest: 'dist/jquery.<%= pkg.name %>.langs.min.js'
            }
        },
        cssmin: {
            allcss: {
                files: [{
                    expand: true,
                    cwd: 'css',
                    src: ['*.css'],
                    dest: 'dist',
                    ext: '.min.css'
                }]
            }
        },
        mocha_phantomjs: {
            all: {
                options: {
                    urls: ['http://localhost:9000/test/test.html']
                }
            }
        },
        jshint: {
            options: {
                reporter: require('jshint-stylish')
            },
            gruntfile: {
                options: {
                    jshintrc: '.jshintrc'
                },
                src: 'Gruntfile.js'
            },
            src: {
                options: {
                    jshintrc: '.jshintrc'
                },
                src: ['src/**/*.js']
            },
            test: {
                options: {
                    jshintrc: 'test/.jshintrc'
                },
                src: ['test/*.js']
            }
        },
        watch: {
            gruntfile: {
                files: '<%= jshint.gruntfile.src %>',
                tasks: ['jshint:gruntfile']
            },
            src: {
                files: '<%= jshint.src.src %>',
                tasks: ['jshint:src', 'mocha_phantomjs']
            },
            test: {
                files: ['test/test.html', '<%= jshint.test.src %>'],
                tasks: ['jshint:test', 'mocha_phantomjs']
            }
        },
        connect: {
            server: {
                options: {
                    hostname: '*',
                    port: 9000
                }
            }
        },
        version: {
            VERSION: {
                options: {
                    prefix: ''
                },
                src: ['VERSION']
            },
            bower: {
                src: ['bower.json']
            },
            manifest: {
                options: {
                    prefix: 'Version\\s+'
                },
                src: ['manifest.appcache']
            }
        }
    });

    grunt.loadNpmTasks('grunt-mocha-phantomjs');
    grunt.loadNpmTasks('grunt-contrib-cssmin');
    grunt.loadNpmTasks('grunt-version');

    // Default task.
    grunt.registerTask('default', ['jshint', 'clean', 'version', 'concat', 'connect', 'mocha_phantomjs', 'uglify', 'cssmin']);
    grunt.registerTask('buildonly', ['clean', 'version', 'concat', 'uglify', 'cssmin']);
    grunt.registerTask('server', function () {
        grunt.log.warn('The `server` task has been deprecated. Use `grunt serve` to start a server.');
        grunt.task.run(['serve']);
    });
    grunt.registerTask('serve', ['connect', 'watch']);
    grunt.registerTask('test', ['jshint', 'connect', 'mocha_phantomjs']);
};
